summaryrefslogtreecommitdiff
path: root/mysql-test/mysql-stress-test.pl
diff options
context:
space:
mode:
authorunknown <knielsen@knielsen-hq.org>2010-04-28 14:52:24 +0200
committerunknown <knielsen@knielsen-hq.org>2010-04-28 14:52:24 +0200
commitb1e00b6be81c80b09d11085d77d86978e26df988 (patch)
treebb1fdd7363fbf2580572ac9a56dbd4c933cc4c0d /mysql-test/mysql-stress-test.pl
parent1f683a7270e63abfadce20c6f51370621ff065e1 (diff)
parentc9cfd2df5f2f58c2cdf716999ebea252c307333f (diff)
downloadmariadb-git-b1e00b6be81c80b09d11085d77d86978e26df988.tar.gz
Merge MySQL 5.1.46 into MariaDB.
Still two test failures to be solved: main.myisam and main.subselect.
Diffstat (limited to 'mysql-test/mysql-stress-test.pl')
-rwxr-xr-xmysql-test/mysql-stress-test.pl11
1 files changed, 8 insertions, 3 deletions
diff --git a/mysql-test/mysql-stress-test.pl b/mysql-test/mysql-stress-test.pl
index 8b94ba1404d..378eed9ef68 100755
--- a/mysql-test/mysql-stress-test.pl
+++ b/mysql-test/mysql-stress-test.pl
@@ -122,8 +122,8 @@ $opt_threads=1;
$pid_file="mysql_stress_test.pid";
$opt_mysqltest= ($^O =~ /mswin32/i) ? "mysqltest.exe" : "mysqltest";
$opt_check_tests_file="";
-# OBM adding a setting for 'max-connect-retries=7' the default of 500 is to high
-@mysqltest_args=("--silent", "-v", "--skip-safemalloc", "--max-connect-retries=7");
+# OBM adding a setting for 'max-connect-retries=20' the default of 500 is to high
+@mysqltest_args=("--silent", "-v", "--skip-safemalloc", "--max-connect-retries=20");
# Client ip address
$client_ip=inet_ntoa((gethostbyname(hostname()))[4]);
@@ -150,7 +150,12 @@ $client_ip=~ s/\.//g;
%error_strings = ( 'Failed in mysql_real_connect()' => S1,
'Can\'t connect' => S1,
- 'not found (Errcode: 2)' => S1 );
+ 'not found (Errcode: 2)' => S1,
+ 'does not exist' => S1,
+ 'Could not open connection \'default\' after \d+ attempts' => S1,
+ 'wrong errno ' => S3,
+ 'Result length mismatch' => S4,
+ 'Result content mismatch' => S4);
%error_codes = ( 1012 => S2, 1015 => S2, 1021 => S2,
1027 => S2, 1037 => S2, 1038 => S2,